@@ -9,16 +9,18 @@
 //
 //
 #ifndef _BSDSENSOR_H_
-#define _BSDSENSOR_H__
+#define _BSDSENSOR_H_
+
+#include "sensorfieldmeter.h"
+#include "xosview.h"
+
+#define NAMESIZE 32
 
 
-#include "fieldmeter.h"
-#include <string>
-
-
-class BSDSensor : public FieldMeter {
+class BSDSensor : public SensorFieldMeter {
 public:
-	BSDSensor( XOSView *parent, const char *name, const char *high, const char *label, const char *caption, int nbr);
+	BSDSensor( XOSView *parent, const char *name, const char *high,
+	           const char *low, const char *label, const char *caption, int nbr );
 	~BSDSensor( void );
 
 	const char *name( void ) const { return "BSDSensor"; }
@@ -29,7 +31,8 @@ protected:
 	void getsensor( void );
 
 private:
-	std::string name_, high_;
+	char name_[NAMESIZE], highname_[NAMESIZE], lowname_[NAMESIZE];
+	char val_[NAMESIZE], highval_[NAMESIZE], lowval_[NAMESIZE];
 	int nbr_;
 };
 
