@@ -1,6 +1,5 @@
 //  
-// $Id$
-//  Initial port performed by Stefan Eilemann (eile@sgi.com)
+//  Initial port performed by Stefan Eilemann (eilemann@gmail.com)
 //
 
 #include "gfxmeter.h"
@@ -9,6 +8,9 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <invent.h>
+#include <iostream>
+
+using namespace std;
 
 // GfxMeter display swapbuffers per second. max is base rate for one gfx pipe.
 
@@ -70,7 +72,7 @@ void GfxMeter::checkResources(void)
         //  prevent this whole problem, the gfx meter can not be a decay
         //  meter.  The gfx is a decaying average kind of thing anyway,
         //  so having a decaying gfx average is redundant.
-        cerr << "Warning:  The gfxmeter can not be configured as a decay\n"
+           std::cerr << "Warning:  The gfxmeter can not be configured as a decay\n"
              << "  meter. See the source code (" <<__FILE__<< ") for further\n"
              << "  details.\n";
         dodecay_ = 0;
@@ -106,8 +108,7 @@ void GfxMeter::getgfxinfo(void)
                 setfieldcolor( 0, warngfxcol_ );
             else
                 setfieldcolor( 0, critgfxcol_ );
-        if (dolegends_)
-            drawlegend();
+	drawlegend();
         lastalarmstate = alarmstate;
     }
   
