@@ -8,9 +8,9 @@
 #define _NETMETER_H_
 
 #include "fieldmetergraph.h"
-#include "timer.h"
+#include "xosview.h"
+#include <string>
 
-class Host;
 
 class NetMeter : public FieldMeterGraph {
 public:
@@ -19,25 +19,16 @@ public:
 
   const char *name( void ) const { return "NetMeter"; }
   void checkevent( void );
-
   void checkResources( void );
-protected:
-  float maxpackets_;
-  std::string netIface_;
-  bool ignored_;
+
 private:
-  int _ipsock;
-  Timer _timer;
+  void getProcStats( unsigned long long &totin, unsigned long long &totout );
+  void getSysStats( unsigned long long &totin, unsigned long long &totout );
+  float _maxpackets;
+  std::string _netIface;
+  bool _usesysfs, _ignored;
   unsigned long long _lastBytesIn, _lastBytesOut;
-  const char *_netfilename;
-  bool _usechains;
-  int _bytesInDev;
-
-  void adjust(void);
-  void checkOSVersion(void);
-
-  void checkeventOld(void);
-  void checkeventNew(void);
 };
 
+
 #endif
